
========================================
Welcome to django SHOP's documentation!
========================================

User Manual
============

The "instructions" :)

.. toctree::
    :maxdepth: 1
    :numbered:

    tutorial

    getting-started
    templatetags
    signals
    contributing

How to
======

Various short articles on how to do specific things

.. toctree::
    :maxdepth: 2
    :numbered:

    howto/how-to-product
    howto/how-to-cart-mod
    howto/how-to-payment
    howto/how-to-shipping
    howto/how-to-interact-with-the-cart
    howto/how-to-secure-your-views

Advanced how to
===============

More focused short articles, focusing on less general and more advanced use cases.

.. toctree::
    :maxdepth: 2
    :numbered:

    howto/how-to-extend-django-shop-models
    howto/how-to-use-your-own-addressmodel


Reference
==========

Reference sheets and lists regarding django SHOP

.. toctree::
    :maxdepth: 1
    :numbered:

    plugins
    settings

The name
========

The official name of this project is **django SHOP**.

**Django SHOP** should be capitalised at the start of sentences and in
title-case headings.

When referring to the package, repositories and any other things in which
spaces are not permitted, use **django-shop**.
